# openai api key 免费分享
- 客户端使用教程
```python
import openai

openai.api_base = 'https://api.openai-proxy.com/v1' # 'https://proxy.aidashi.wiki/v1'
openai.api_key = "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"
prompt = "你好"
completion = openai.Completion.create(prompt=prompt, stream=True, model="text-davinci-003", max_tokens=1000)
for c in completion:
    print(c.choices[0].text, end='')
```


|     | API KEY                                             | 账号类型   |   总额度 |   本月使用额度 |   上月使用额度 |   剩余额度 | api类型   |
|----:|:----------------------------------------------------|:-----------|---------:|---------------:|---------------:|-----------:|:----------|
|   0 | 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 | free       |       18 |           0    |           0    |      18    | GPT3.5    |
|   1 | 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 | free       |       18 |           0    |           0    |      18    | GPT3.5    |
|   2 | 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 | free       |       18 |           0.16 |           0    |      17.84 | GPT3.5    |
|   3 | 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 | free       |       18 |           0.2  |           0    |      17.8  | GPT3.5    |
|   4 | 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 | free       |       18 |           0.21 |           0    |      17.79 | GPT3.5    |
|   5 | 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 | free       |       18 |           0.22 |           0    |      17.78 | GPT3.5    |
|   6 | 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 | free       |       18 |           0.25 |           0    |      17.75 | GPT3.5    |
|   7 | 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 | free       |       18 |           0.25 |           0    |      17.75 | GPT3.5    |
|   8 | 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 | free       |       18 |           0.25 |           0    |      17.75 | GPT3.5    |
|   9 | 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 | free       |       18 |           0.26 |           0    |      17.74 | GPT3.5    |
|  10 | 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 | free       |       18 |           0.26 |           0    |      17.74 | GPT3.5    |
|  11 | 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 | free       |       18 |           0.27 |           0    |      17.73 | GPT3.5    |
|  12 | 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 | free       |       18 |           0.27 |           0    |      17.73 | GPT3.5    |
|  13 | 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 | free       |       18 |           0.27 |           0    |      17.73 | GPT3.5    |
|  14 | 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 | free       |       18 |           0.28 |           0    |      17.72 | GPT3.5    |
|  15 | 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 | free       |       18 |           0.28 |           0    |      17.72 | GPT3.5    |
|  16 | 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 | free       |       18 |           0.29 |           0    |      17.71 | GPT3.5    |
|  17 | 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 | free       |       18 |           0.33 |           0    |      17.67 | GPT3.5    |
|  18 | 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 | free       |       18 |           0.35 |           0    |      17.65 | GPT3.5    |
|  19 | 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 | free       |       18 |           0.37 |           0    |      17.63 | GPT3.5    |
|  20 | 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 | free       |       18 |           0.37 |           0    |      17.63 | GPT3.5    |
|  21 | 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 | free       |       18 |           0.38 |           0    |      17.62 | GPT3.5    |
|  22 | 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 | free       |       18 |           0.42 |           0    |      17.58 | GPT3.5    |
|  23 | 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 | free       |       18 |           0.43 |           0    |      17.57 | GPT3.5    |
|  24 | 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 | free       |       18 |           0.43 |           0    |      17.57 | GPT3.5    |
|  25 | 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 | free       |       18 |           0.44 |           0    |      17.55 | GPT3.5    |
|  26 | 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 | free       |       18 |           0.22 |           0.07 |      17.5  | GPT3.5    |
|  27 | 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 | free       |       18 |           0.52 |           0    |      17.48 | GPT3.5    |
|  28 | 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 | free       |       18 |           0.54 |           0    |      17.46 | GPT3.5    |
|  29 | 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 | free       |       18 |           0.57 |           0    |      17.43 | GPT3.5    |
|  30 | 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 | free       |       18 |           0.58 |           0    |      17.42 | GPT3.5    |
|  31 | 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 | free       |       18 |           0.6  |           0    |      17.4  | GPT3.5    |
|  32 | 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 | free       |       18 |           0.63 |           0    |      17.37 | GPT3.5    |
|  33 | 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 | free       |       18 |           0.66 |           0    |      17.34 | GPT3.5    |
|  34 | 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 | free       |       18 |           0.67 |           0    |      17.33 | GPT3.5    |
|  35 | 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 | free       |       18 |           0.68 |           0    |      17.32 | GPT3.5    |
|  36 | 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 | free       |       18 |           0.71 |           0    |      17.29 | GPT3.5    |
|  37 | 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 | free       |       18 |           0.78 |           0    |      17.22 | GPT3.5    |
|  38 | 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 | free       |       18 |           0.79 |           0    |      17.21 | GPT3.5    |
|  39 | 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 | free       |       18 |           0.83 |           0    |      17.17 | GPT3.5    |
|  40 | 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 | free       |       18 |           0.84 |           0    |      17.16 | GPT3.5    |
|  41 | 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 | free       |       18 |           0.85 |           0    |      17.15 | GPT3.5    |
|  42 | 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 | free       |       18 |           0.85 |           0    |      17.15 | GPT3.5    |
|  43 | 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 | free       |       18 |           0.91 |           0    |      17.09 | GPT3.5    |
|  44 | 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 | free       |       18 |           0.93 |           0    |      17.07 | GPT3.5    |
|  45 | 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 | free       |       18 |           0.94 |           0    |      17.06 | GPT3.5    |
|  46 | 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 | free       |       18 |           0.95 |           0    |      17.05 | GPT3.5    |
|  47 | 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 | free       |       18 |           0.96 |           0    |      17.04 | GPT3.5    |
|  48 | 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 | free       |       18 |           0.99 |           0    |      17.01 | GPT3.5    |
|  49 | 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 | free       |       18 |           0.99 |           0    |      17.01 | GPT3.5    |
|  50 | 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 | free       |       18 |           1.03 |           0    |      16.97 | GPT3.5    |
|  51 | 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 | free       |       18 |           1.03 |           0    |      16.97 | GPT3.5    |
|  52 | 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 | free       |       18 |           1.07 |           0    |      16.93 | GPT3.5    |
|  53 | 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 | free       |       18 |           1.09 |           0    |      16.91 | GPT3.5    |
|  54 | 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 | free       |       18 |           1.12 |           0    |      16.88 | GPT3.5    |
|  55 | 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 | free       |       18 |           1.13 |           0    |      16.87 | GPT3.5    |
|  56 | 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 | free       |       18 |           1.14 |           0    |      16.86 | GPT3.5    |
|  57 | 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 | free       |       18 |           1.19 |           0    |      16.81 | GPT3.5    |
|  58 | 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 | free       |       18 |           1.23 |           0    |      16.77 | GPT3.5    |
|  59 | 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 | free       |       18 |           1.36 |           0    |      16.64 | GPT3.5    |
|  60 | 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 | free       |       18 |           1.35 |           0    |      16.63 | GPT3.5    |
|  61 | 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 | free       |       18 |           1.4  |           0    |      16.6  | GPT3.5    |
|  62 | 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 | free       |       18 |           1.38 |           0    |      16.58 | GPT3.5    |
|  63 | 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 | free       |       18 |           1.44 |           0    |      16.56 | GPT3.5    |
|  64 | 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 | free       |       18 |           1.45 |           0    |      16.55 | GPT3.5    |
|  65 | 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 | free       |       18 |           1.46 |           0    |      16.54 | GPT3.5    |
|  66 | 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 | free       |       18 |           1.56 |           0    |      16.44 | GPT3.5    |
|  67 | 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 | free       |       18 |           1.57 |           0    |      16.43 | GPT3.5    |
|  68 | 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 | free       |       18 |           1.61 |           0    |      16.39 | GPT3.5    |
|  69 | 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 | free       |       18 |           1.64 |           0    |      16.36 | GPT3.5    |
|  70 | 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 | free       |       18 |           1.66 |           0    |      16.34 | GPT3.5    |
|  71 | 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 | free       |       18 |           1.66 |           0    |      16.34 | GPT3.5    |
|  72 | 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 | free       |       18 |           1.67 |           0    |      16.33 | GPT3.5    |
|  73 | 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 | free       |       18 |           1.68 |           0    |      16.32 | GPT3.5    |
|  74 | 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 | free       |       18 |           1.72 |           0    |      16.28 | GPT3.5    |
|  75 | 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 | free       |       18 |           1.75 |           0    |      16.25 | GPT3.5    |
|  76 | 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 | free       |       18 |           1.76 |           0    |      16.24 | GPT3.5    |
|  77 | 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 | free       |       18 |           1.79 |           0    |      16.21 | GPT3.5    |
|  78 | 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 | free       |       18 |           1.77 |           0.04 |      16.18 | GPT3.5    |
|  79 | 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 | free       |       18 |           1.85 |           0    |      16.15 | GPT3.5    |
|  80 | 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 | free       |       18 |           1.85 |           0    |      16.14 | GPT3.5    |
|  81 | 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 | free       |       18 |           1.91 |           0    |      16.09 | GPT3.5    |
|  82 | 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 | free       |       18 |           1.92 |           0    |      16.08 | GPT3.5    |
|  83 | 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 | free       |       18 |           1.93 |           0    |      16.07 | GPT3.5    |
|  84 | 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 | free       |       18 |           1.96 |           0    |      16.04 | GPT3.5    |
|  85 | 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 | free       |       18 |           1.97 |           0    |      16.03 | GPT3.5    |
|  86 | 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 | free       |       18 |           1.99 |           0    |      16.01 | GPT3.5    |
|  87 | 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 | free       |       18 |           2.03 |           0    |      15.97 | GPT3.5    |
|  88 | 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 | free       |       18 |           2.08 |           0    |      15.92 | GPT3.5    |
|  89 | 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 | free       |       18 |           2.09 |           0    |      15.91 | GPT3.5    |
|  90 | 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 | free       |       18 |           2.14 |           0    |      15.86 | GPT3.5    |
|  91 | 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 | free       |       18 |           2.16 |           0    |      15.84 | GPT3.5    |
|  92 | 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 | free       |       18 |           2.21 |           0    |      15.79 | GPT3.5    |
|  93 | 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 | free       |       18 |           2.21 |           0    |      15.79 | GPT3.5    |
|  94 | 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 | free       |       18 |           2.3  |           0    |      15.7  | GPT3.5    |
|  95 | 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 | free       |       18 |           2.34 |           0    |      15.66 | GPT3.5    |
|  96 | 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 | free       |       18 |           2.39 |           0    |      15.61 | GPT3.5    |
|  97 | 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 | free       |       18 |           0.92 |           0    |      15.57 | GPT3.5    |
|  98 | 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 | free       |       18 |           2.44 |           0    |      15.56 | GPT3.5    |
|  99 | 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 | free       |       18 |           2.5  |           0    |      15.5  | GPT3.5    |
| 100 | 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 | free       |       18 |           2.51 |           0    |      15.48 | GPT3.5    |
| 101 | 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 | free       |       18 |           2.58 |           0    |      15.42 | GPT3.5    |
| 102 | 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 | free       |       18 |           2.65 |           0    |      15.34 | GPT3.5    |
| 103 | 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 | free       |       18 |           2.67 |           0    |      15.33 | GPT3.5    |
| 104 | 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 | free       |       18 |           2.7  |           0    |      15.3  | GPT3.5    |
| 105 | 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 | free       |       18 |           2.71 |           0    |      15.29 | GPT3.5    |
| 106 | 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 | free       |       18 |           2.72 |           0    |      15.28 | GPT3.5    |
| 107 | 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 | free       |       18 |           2.74 |           0    |      15.26 | GPT3.5    |
| 108 | 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 | free       |       18 |           2.74 |           0    |      15.26 | GPT3.5    |
| 109 | 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 | free       |       18 |           2.75 |           0    |      15.25 | GPT3.5    |
| 110 | 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 | free       |       18 |           2.8  |           0    |      15.2  | GPT3.5    |
| 111 | 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 | free       |       18 |           2.82 |           0    |      15.18 | GPT3.5    |
| 112 | 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 | free       |       18 |           2.85 |           0    |      15.15 | GPT3.5    |
| 113 | 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 | free       |       18 |           2.93 |           0    |      15.07 | GPT3.5    |
| 114 | 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 | free       |       18 |           1.78 |           0    |      15.07 | GPT3.5    |
| 115 | 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 | free       |       18 |           2.97 |           0.03 |      14.89 | GPT3.5    |
| 116 | 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 | free       |       18 |           3.19 |           0    |      14.81 | GPT3.5    |
| 117 | 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 | free       |       18 |           3.19 |           0    |      14.81 | GPT3.5    |
| 118 | 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 | free       |       18 |           3.26 |           0    |      14.74 | GPT3.5    |
| 119 | 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 | free       |       18 |           2.52 |           0.19 |      14.72 | GPT3.5    |
| 120 | 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 | free       |       18 |           3.3  |           0    |      14.7  | GPT3.5    |
| 121 | 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 | free       |       18 |           3.31 |           0    |      14.69 | GPT3.5    |
| 122 | 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 | free       |       18 |           3.24 |           0.11 |      14.65 | GPT3.5    |
| 123 | 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 | free       |       18 |           3.36 |           0    |      14.64 | GPT3.5    |
| 124 | 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 | free       |       18 |           3.37 |           0    |      14.63 | GPT3.5    |
| 125 | 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 | free       |       18 |           3.39 |           0    |      14.6  | GPT3.5    |
| 126 | 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 | free       |       18 |           3.39 |           0    |      14.6  | GPT3.5    |
| 127 | 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 | free       |       18 |           3.42 |           0    |      14.57 | GPT3.5    |
| 128 | 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 | free       |       18 |           3.45 |           0    |      14.55 | GPT3.5    |
| 129 | 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 | free       |       18 |           3.58 |           0    |      14.42 | GPT3.5    |
| 130 | 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 | free       |       18 |           3.59 |           0    |      14.41 | GPT3.5    |
| 131 | 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 | free       |       18 |           3.68 |           0    |      14.32 | GPT3.5    |
| 132 | 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 | free       |       18 |           3.73 |           0    |      14.27 | GPT3.5    |
| 133 | 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 | free       |       18 |           3.37 |           0    |      14.23 | GPT3.5    |
| 134 | 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 | free       |       18 |           3.78 |           0    |      14.22 | GPT3.5    |
| 135 | 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 | free       |       18 |           3.86 |           0    |      14.14 | GPT3.5    |
| 136 | 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 | free       |       18 |           2.04 |           0.04 |      14.11 | GPT3.5    |
| 137 | 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 | free       |       18 |           3.92 |           0    |      14.08 | GPT3.5    |
| 138 | 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 | free       |       18 |           4.02 |           0    |      13.98 | GPT3.5    |
| 139 | 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 | free       |       18 |           3.96 |           0    |      13.86 | GPT3.5    |
| 140 | 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 | free       |       18 |           4.23 |           0    |      13.77 | GPT3.5    |
| 141 | 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 | free       |       18 |           4.31 |           0    |      13.69 | GPT3.5    |
| 142 | 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 | free       |       18 |           4.39 |           0    |      13.61 | GPT3.5    |
| 143 | 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 | free       |       18 |           4.42 |           0    |      13.58 | GPT3.5    |
| 144 | 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 | free       |       18 |           4.46 |           0    |      13.53 | GPT3.5    |
| 145 | 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 | free       |       18 |           4.47 |           0    |      13.53 | GPT3.5    |
| 146 | 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 | free       |       18 |           4.48 |           0    |      13.52 | GPT3.5    |
| 147 | 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 | free       |       18 |           4.49 |           0    |      13.51 | GPT3.5    |
| 148 | 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 | free       |       18 |           4.33 |           0.16 |      13.51 | GPT3.5    |
| 149 | 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 | free       |       18 |           4.49 |           0    |      13.51 | GPT3.5    |
| 150 | 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 | free       |       18 |           4.52 |           0    |      13.48 | GPT3.5    |
| 151 | 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 | free       |       18 |           4.53 |           0    |      13.47 | GPT3.5    |
| 152 | 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 | free       |       18 |           4.65 |           0    |      13.35 | GPT3.5    |
| 153 | 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 | free       |       18 |           4.66 |           0    |      13.34 | GPT3.5    |
| 154 | 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 | free       |       18 |           4.8  |           0    |      13.2  | GPT3.5    |
| 155 | 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 | free       |       18 |           4.81 |           0    |      13.19 | GPT3.5    |
| 156 | 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 | free       |       18 |           5.02 |           0    |      12.98 | GPT3.5    |
| 157 | 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 | free       |       18 |           5.11 |           0    |      12.89 | GPT3.5    |
| 158 | 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 | free       |       18 |           5.15 |           0    |      12.85 | GPT3.5    |
| 159 | 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 | free       |       18 |           5.18 |           0    |      12.82 | GPT3.5    |
| 160 | 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 | free       |       18 |           5.18 |           0    |      12.82 | GPT3.5    |
| 161 | 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 | free       |       18 |           5.19 |           0    |      12.81 | GPT3.5    |
| 162 | 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 | free       |       18 |           5.29 |           0    |      12.71 | GPT3.5    |
| 163 | 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 | free       |       18 |           5.3  |           0    |      12.7  | GPT3.5    |
| 164 | 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 | free       |       18 |           5.25 |           0    |      12.62 | GPT3.5    |
| 165 | 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 | free       |       18 |           5.39 |           0    |      12.61 | GPT3.5    |
| 166 | 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 | free       |       18 |           5.45 |           0    |      12.55 | GPT3.5    |
| 167 | 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 | free       |       18 |           5.49 |           0    |      12.51 | GPT3.5    |
| 168 | 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 | free       |       18 |           5.5  |           0    |      12.5  | GPT3.5    |
| 169 | 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 | free       |       18 |           5.66 |           0    |      12.34 | GPT3.5    |
| 170 | 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 | free       |       18 |           5.75 |           0    |      12.25 | GPT3.5    |
| 171 | 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 | free       |       18 |           5.75 |           0    |      12.13 | GPT3.5    |
| 172 | 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 | free       |       18 |           5.99 |           0    |      12.01 | GPT3.5    |
| 173 | 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 | free       |       18 |           6.08 |           0    |      11.92 | GPT3.5    |
| 174 | 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 | free       |       18 |           6.22 |           0    |      11.78 | GPT3.5    |
| 175 | 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 | free       |       18 |           6.24 |           0    |      11.76 | GPT3.5    |
| 176 | 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 | free       |       18 |           6.27 |           0    |      11.73 | GPT3.5    |
| 177 | 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 | free       |       18 |           6.68 |           0    |      11.32 | GPT3.5    |
| 178 | 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 | free       |       18 |           6.69 |           0    |      11.31 | GPT3.5    |
| 179 | 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 | free       |       18 |           6.86 |           0    |      11.14 | GPT3.5    |
| 180 | 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 | free       |       18 |           6.91 |           0    |      11.08 | GPT3.5    |
| 181 | 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 | free       |       18 |           7.01 |           0    |      10.99 | GPT3.5    |
| 182 | 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 | free       |       18 |           7.28 |           0    |      10.72 | GPT3.5    |
| 183 | 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 | free       |       18 |           7.53 |           0    |      10.47 | GPT3.5    |
| 184 | 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 | free       |       18 |           8.07 |           0    |       9.93 | GPT3.5    |
| 185 | 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 | free       |       18 |           8.38 |           0    |       9.62 | GPT3.5    |
| 186 | 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 | free       |       18 |           8.39 |           0    |       9.61 | GPT3.5    |
| 187 | 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 | free       |       18 |           8.44 |           0    |       9.56 | GPT3.5    |
| 188 | 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 | free       |       18 |           8.46 |           0    |       9.54 | GPT3.5    |
| 189 | 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 | free       |       18 |           8.47 |           0    |       9.53 | GPT3.5    |
| 190 | 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 | free       |       18 |           8.54 |           0    |       9.46 | GPT3.5    |
| 191 | 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 | free       |       18 |           8.73 |           0    |       9.27 | GPT3.5    |
| 192 | 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 | free       |       18 |           8.7  |           0    |       9.22 | GPT3.5    |
| 193 | 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 | free       |       18 |           8.89 |           0    |       9.11 | GPT3.5    |
| 194 | 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 | free       |       18 |           9.47 |           0    |       8.52 | GPT3.5    |
| 195 | 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 | free       |       18 |           9.51 |           0    |       8.49 | GPT3.5    |
| 196 | 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 | free       |       18 |           9.78 |           0    |       8.21 | GPT3.5    |
| 197 | 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 | free       |       18 |           9.94 |           0    |       8.06 | GPT3.5    |
| 198 | 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 | free       |       18 |          10.28 |           0    |       7.72 | GPT3.5    |
| 199 | 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 | free       |       18 |          10.34 |           0    |       7.66 | GPT3.5    |
| 200 | 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 | free       |       18 |          10.72 |           0    |       7.28 | GPT3.5    |
| 201 | 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 | free       |       18 |          11.17 |           0.02 |       6.81 | GPT3.5    |
| 202 | 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 | free       |       18 |          12.01 |           0    |       5.99 | GPT3.5    |
| 203 | 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 | free       |       18 |          12.02 |           0    |       5.98 | GPT3.5    |
| 204 | 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 | free       |       18 |          10.65 |           0    |       5.95 | GPT3.5    |
| 205 | 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 | free       |       18 |           0.29 |          11.69 |       5.77 | GPT3.5    |
| 206 | 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 | free       |       18 |          12.52 |           0    |       5.48 | GPT3.5    |
| 207 | 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 | free       |       18 |          12.55 |           0    |       5.45 | GPT3.5    |
| 208 | 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 | free       |       18 |          12.62 |           0    |       5.38 | GPT3.5    |
| 209 | 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 | free       |       18 |          12.78 |           0    |       5.22 | GPT3.5    |
